@@ -1,10 +1,10 @@
-context("KNN forecasting function")
-
-expect_error(knn_forecasting(ts(1:5), h = 1, 3:1, 2))
-
-expect_error(knn_forecasting(ts(1:5), h = 1, 0:2, 2))
-
-expect_error(knn_forecasting(ts(1:5), h = 1, lags = 3:5, k = 1))
+test_that("errors calling knn_forecasting", {
+  expect_error(knn_forecasting(ts(1:5), h = 1, lags = 3:1, k = 2))
+  expect_error(knn_forecasting(ts(1:5), h = 1, lags = 0:2, k = 2))
+  expect_error(knn_forecasting(ts(1:5), h = 1, lags = 3:5, k = 1))
+  expect_error(knn_forecasting(ts(1:5), h = 1, lags = 1, k = 1, transform = "additive"))
+  expect_error(knn_forecasting(ts(1:5), h = 1, lags = 1, k = 1, transform = "multiplicative"))
+})
 
 pred <- knn_forecasting(ts(c(2, 3, 1, 5, 4, 0, 7, 1, 2)), h = 2, lags = 1:2, k = 2,
                         msas = "MIMO", transform = "none")
